==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Todas as assinaturas desta petição serão removidas. Tem certeza que deseja continuar?',
	'aucune_signature' => 'Nenhuma assinatura',

	// B
	'bouton_checkbox_envoi_message' => 'possibilidade de enviar mensagem',
	'bouton_checkbox_indiquer_site' => 'tornar obrigatória a indicação de um website',
	'bouton_checkbox_signature_unique_email' => 'apenas uma assinatura por endereço de email',
	'bouton_checkbox_signature_unique_site' => 'somente uma assinatura por website',
	'bouton_radio_activer_petition' => 'Ativar a petição',
	'bouton_radio_pas_petition' => 'Sem petição',
	'bouton_radio_petition_activee' => 'Petição ativada',
	'bouton_radio_supprimer_petition' => 'Excluir a petição',

	// F
	'filtre' => 'Filtro:',
	'form_pet_adresse_site' => 'Endereço de seu site',
	'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este código...',
	'form_pet_confirmation' => 'Por favor, confirme a sua assinatura:',
	'form_pet_deja_signe' => 'Você já assinou este texto.',
	'form_pet_envoi_mail_confirmation' => 'Uma mensagem de confirmação acabou de ser enviada para @email@. Para validar sua assinatura, visite o endereço web mencionado na mensagem.',
	'form_pet_mail_confirmation' => 'Bom dia,

Você pediu para assinar a petição:
@titre@.

Você forneceu as informações abaixo:
    Nome: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para validar a sua assinatura, basta se conectar ao
endereço abaixo (caso contrário, seu pedido será
rejeitado):

    @url@


Obrigado por participar
',
	'form_pet_message_commentaire' => 'Uma mensagem ou comentário?',
	'form_pet_nom_site2' => 'Nome de seu website',
	'form_pet_probleme_liens' => 'Por favor, retire os links hipertexto da sua mensagem.',
	'form_pet_probleme_technique' => 'Problema técnico: as assinaturas estão suspensas temporariamente.',
	'form_pet_signature_validee' => 'Sua assinatura foi validada. Obrigado!',
	'form_pet_site_deja_enregistre' => 'Este site já está cadastrado',
	'form_pet_url_invalide' => 'O URL que você informou não é válido.',
	'form_pet_votre_email' => 'Seu endereço de e-mail',
	'form_pet_votre_nom' => 'Seu nome ou apelido',
	'form_pet_votre_site' => 'Se você tem um website, você pode informá-lo abaixo',

	// I
	'icone_relancer_signataire' => 'Recontactar signatário',
	'icone_relancer_signataires' => 'Recontactar signatários',
	'icone_suivi_petitions' => 'Seguir / gerenciar petições',
	'icone_supprimer_signature' => 'Apagar esta assinatura',
	'icone_supprimer_signatures' => 'Remover assinaturas',
	'icone_valider_signature' => 'Validar esta assinatura',
	'icone_valider_signatures' => 'Validar assinaturas',
	'info_adresse_email' => 'ENDEREÇO DE E-MAIL:',
	'info_fonctionnement_petition' => 'Funcionamento da petição:',
	'info_signature_supprimee' => 'Assinatura excluída',
	'info_signature_supprimee_erreur' => 'Erro: este código de exclusão não corresponde a nenhuma assinatura',
	'info_site_web' => 'WEBSITE:',
	'info_texte_message' => 'Texto de sua mensagem:',

	// L
	'lien_reponse_article' => 'Resposta à matéria',

	// N
	'nombre_signatures' => '@nb@ assinaturas',

	// S
	'sans_nom' => 'Anônimo',
	'signatures_article' => 'Assinaturas da matéria:',
	'signatures_aucune' => 'Nenhuma',
	'signatures_meme_auteur' => 'Assinaturas do mesmo autor',
	'signatures_meme_site' => 'Assinaturas com o mesmo site',
	'signatures_poubelle' => 'Removidas',
	'signatures_prop' => 'Na fila',
	'signatures_publie' => 'Confirmadas',
	'signatures_recherche_label' => 'Buscar assinaturas:',
	'signatures_selection' => 'Selecionar assinaturas:',
	'signatures_toutes' => 'Todas',
	'statut_poubelle' => 'Na lixeira',
	'statut_prop' => 'Aguardando validação',
	'statut_publie' => 'Confirmada',

	// T
	'texte_descriptif_petition' => 'Descrição da petição',
	'titre_page_controle_petition' => 'Monitoramento das petições',
	'titre_petition' => 'Petição',
	'titre_petitions' => 'Petições',
	'titre_selection_action' => 'Seleção',
	'titre_signatures_attente' => 'Assinaturas aguardando validação',
	'titre_signatures_publie' => 'Assinaturas confirmadas',
	'titre_suivi_petition' => 'Monitoramento de petições',
	'tout_voir' => 'Ver tudo',

	// U
	'une_signature' => '1 assinatura',

	// V
	'voir_signatures_objet' => 'Ver assinaturas'
);

?>

==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_pt_br.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=pt_br
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// F
	'form_pet_adresse_site' => 'Endereço do seu site', # MODIF
	'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este código...', # MODIF
	'form_pet_confirmation' => 'Por favor, confirme a sua assinatura:',
	'form_pet_deja_signe' => 'Você já assinou este texto.',
	'form_pet_envoi_mail_confirmation' => 'Um e-mail de confirmação acabou de ser enviado para @email@. Você deverá visitar o endereço web mencionado na mensagem para validar a sua assinatura.', # MODIF
	'form_pet_mail_confirmation' => 'Bom dia,

Você pediu para assinar a petição:
@titre@.

Você forneceu as informações abaixo:
    Nome: @nom_email@
    Site: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para validar a sua assinatura, basta se conectar ao
endereço abaixo (caso contrário, seu pedido será
rejeitado):

    @url@


Obrigado por participar
',
	'form_pet_nom_site2' => 'Nome do seu website', # MODIF
	'form_pet_probleme_liens' => 'Por favor, retire os links hipertexto da sua mensagem.',
	'form_pet_probleme_technique' => 'Problema técnico: as assinaturas estão suspensas temporariamente.',
	'form_pet_signature_validee' => 'Sua assinatura foi validada. Obrigado!',
	'form_pet_site_deja_enregistre' => 'Este site já está cadastrado',
	'form_pet_url_invalide' => 'O URL que você informou não é válido.',
	'form_pet_votre_email' => 'Seu endereço de e-mail',
	'form_pet_votre_nom' => 'Seu nome ou apelido', # MODIF
	'form_pet_votre_site' => 'Se você tem um website, você pode informá-lo abaixo',

	// I
	'info_adresse_email' => 'ENDEREÇO DE E-MAIL:',
	'info_signature_supprimee' => 'Assinatura excluída',
	'info_signature_supprimee_erreur' => 'Erro: este código de exclusão não corresponde a nenhuma assinatura', # MODIF
	'info_site_web' => 'WEBSITE:',

	// L
	'lien_reponse_article' => 'Resposta à matéria'
);

?>
